@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Citas",
     "Schedule appointment \"%s\"" : "Programar cita \"%s\"",
     "Schedule an appointment" : "Programar una cita",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Preparar para %s",
     "Follow up for %s" : "Hacer seguimiento de %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Tu cita \"%s\" con %s necesita confirmación",
@@ -61,6 +60,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "No se pudo copiar el enlace de la cita al portapapeles",
     "Preview" : "Previsualizar",
     "Copy link" : "Copiar liga",
+    "Duplicate" : "Duplicar",
     "Edit" : "Editar",
     "Delete" : "Borrar",
     "Create new" : "Crear nuevo",
@@ -69,8 +69,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Activar calendario \"{calendar}\"",
     "Enable untitled calendar" : "Activar calendario sin título",
     "An error occurred, unable to change visibility of the calendar." : "Ocurrió un error, no se pudo cambiar la visibilidad del calendario.",
+    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
+    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
     "Untitled calendar" : "Calendario sin título",
     "Shared with you by" : "Compartido contigo por",
+    "Copy public link" : "Copiar enlace público",
     "Edit and share calendar" : "Editar y compartir calendario",
     "Edit calendar" : "Editar calendario",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejar de compartir el calendario en {countdown} segundo","Dejar de compartir el calendario en {countdown} segundos","Dejar de compartir el calendario en {countdown} segundos"],
@@ -86,8 +89,6 @@ OC.L10N.register(
     "New subscription from link (read-only)" : "Nueva suscripción desde enlace (solo lectura)",
     "Creating subscription …" : "Creando suscripción …",
     "Add public holiday calendar" : "Agregar calendario de días festivos",
-    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
-    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
     "Copy subscription link" : "Copiar enlace de suscripción",
     "Copying link …" : "Copiando enlace …",
     "Copied link" : "Enlace copiado",
@@ -119,7 +120,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "No se pudo copiar el código de incrustación al portapapeles.",
     "Unpublishing calendar failed" : "No se pudo publicar el calendario",
     "Share link" : "Compartir liga",
-    "Copy public link" : "Copiar enlace público",
     "Send link to calendar via email" : "Enviar enlace del calendario por correo electrónico",
     "Enter one address" : "Ingresa una dirección",
     "Sending email …" : "Enviando correo electrónico …",
@@ -287,6 +287,7 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
+    "Copied to clipboard" : "Copiado al portapapeles",
     "No attendees yet" : "Aún no hay asistentes",
     "Attendees" : "Asistentes",
     "Remove group" : "Eliminar grupo",
@@ -383,9 +384,9 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detección automática de la zona horaria determinó que tu zona horaria es UTC.\n      Esto es probablemente el resultado de medidas de seguridad de tu navegador web.\n      Por favor, establece tu zona horaria manualmente en la configuración del calendario.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se encontró tu zona horaria configurada ({timezoneId}). Se usará UTC.\n      Por favor, cambia tu zona horaria en la configuración y reporta este problema.",
+    "Discard changes" : "Descartar cambios",
     "Edit event" : "Editar evento",
     "Event does not exist" : "El evento no existe",
-    "Duplicate" : "Duplicar",
     "Delete this occurrence" : "Eliminar esta ocurrencia",
     "Delete this and all future" : "Eliminar esta y todas las siguientes",
     "All day" : "Todo el día",
@@ -396,6 +397,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["El adjunto requiere acceso compartido","Los adjuntos requieren acceso compartido","Los adjuntos requieren acceso compartido"],
     "Untitled event" : "Evento sin título",
     "Close" : "Cerrar",
+    "This event was cancelled" : "Este evento fue cancelado",
     "Title" : "Título",
     "30 min" : "30 minutos",
     "Participants" : "Participantes",
@@ -489,6 +491,7 @@ OC.L10N.register(
     "This is an event reminder." : "Esto es un recordatorio de evento.",
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Oculto",
     "can edit" : "puede editar",
     "Calendar name …" : "Nombre del calendario …",
