@@ -41,8 +41,11 @@ OC.L10N.register(
     "Delete" : "Izbriši",
     "Create new" : "Stvori novi",
     "An error occurred, unable to change visibility of the calendar." : "Došlo je do pogreške, nije moguće promijeniti vidljivost kalendara.",
+    "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
+    "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
     "Untitled calendar" : "Kalendar bez naslova",
     "Shared with you by" : "S vama podijelio",
+    "Copy public link" : "Kopiraj javnu poveznicu",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekundi","Prekid dijeljenja kalendara za {countdown} sekundi"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekundi","Brisanje kalendara za {countdown} sekundi"],
     "An error occurred, unable to create the calendar." : "Došlo je do pogreške, nije moguće stvoriti kalendar.",
@@ -53,15 +56,15 @@ OC.L10N.register(
     "New calendar with task list" : "Novi kalendar s popisom zadataka",
     "New subscription from link (read-only)" : "Nova pretplata putem poveznice (samo za čitanje)",
     "Creating subscription …" : "Stvaranje pretplate...",
-    "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
-    "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
     "Copy subscription link" : "Kopiraj poveznicu pretplate",
     "Copying link …" : "Kopiranje poveznice...",
     "Copied link" : "Poveznica je kopirana",
     "Could not copy link" : "Kopiranje poveznice nije uspjelo",
     "Export" : "Izvoz",
     "Untitled item" : "Stavka bez naslova",
+    "Unknown calendar" : "Nepoznati kalendar",
     "Could not load deleted calendars and objects" : "Učitavanje izbrisanih kalendara i objekata nije uspjelo",
+    "Could not delete calendar or event" : "Nije moguće izbrisati kalendar ili događaj",
     "Could not restore calendar or event" : "Vraćanje kalendara ili događaja nije uspjelo",
     "Do you really want to empty the trash bin?" : "Želite li zaista isprazniti kantu za smeće?",
     "Empty trash bin" : "Isprazni kantu za smeće",
@@ -80,7 +83,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Šifru za ugradnju nije moguće kopirati u međuspremnik.",
     "Unpublishing calendar failed" : "Neuspješan prekid objave kalendara",
     "Share link" : "Dijeli poveznicu",
-    "Copy public link" : "Kopiraj javnu poveznicu",
     "Send link to calendar via email" : "Pošalji poveznicu na kalendar putem e-pošte",
     "Enter one address" : "Unesi jednu adresu",
     "Sending email …" : "Slanje e-pošte u tijeku...",
@@ -129,6 +131,11 @@ OC.L10N.register(
     "Editing" : "Uređivanje",
     "Default reminder" : "Zadani podsjetnik",
     "Files" : "Datoteke",
+    "_{duration} hour_::_{duration} hours_" : ["{duration} sat","{duration} sata","{duration} sati"],
+    "_{duration} day_::_{duration} days_" : ["{duration} dan","{duration} dana","{duration} dana"],
+    "_{duration} week_::_{duration} weeks_" : ["{duration} tjedan","{duration} tjedna","{duration} tjedana"],
+    "_{duration} month_::_{duration} months_" : ["{duration} mjesec","{duration} mjeseca","{duration} mjeseci"],
+    "_{duration} year_::_{duration} years_" : ["{duration} godina","{duration} godine","{duration} godina"],
     "Update" : "Ažuriraj",
     "(copy)" : "(kopiraj)",
     "Location" : "Lokacija",
@@ -148,6 +155,7 @@ OC.L10N.register(
     "Weekdays" : "Dani u tjednu",
     "Your email address" : "Vaša adresa e-pošte",
     "Back" : "Natrag",
+    "Talk conversation for event" : "Talk razgovor za događaj",
     "Select conversation" : "Odaberi razgovor",
     "on" : "na",
     "at" : "u",
@@ -170,7 +178,9 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
     "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
     "Proceed" : "Nastavi",
+    "Upload from device" : "Prenesi s uređaja",
     "Delete file" : "Izbriši datoteku",
+    "Confirmation" : "Potvrda",
     "Available" : "Dostupno",
     "Not available" : "Nije dostupno",
     "{organizer} (organizer)" : "{organizer} (organizator)",
@@ -264,6 +274,7 @@ OC.L10N.register(
     "Global" : "Globalno",
     "Subscribed" : "Pretplaćen",
     "Subscribe" : "Preplata",
+    "Select a date" : "Odaberi datum",
     "Time:" : "Vrijeme:",
     "Personal" : "Osobno",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Značajka automatskog otkrivanja vremenske zone utvrdila je vašu vremensku zonu kao UTC.\nVjerojatno zbog sigurnosnih mjera vašeg internetskog preglednika.\nRučno postavite vremensku zonu u postavkama kalendara.",
@@ -282,6 +293,7 @@ OC.L10N.register(
     "Participants" : "Sudionici",
     "Submit" : "Šalji",
     "Subscribe to {name}" : "Pretplati se na {name}",
+    "Export {name}" : "Izvezi {name}",
     "Anniversary" : "Godišnjica",
     "Appointment" : "Dogovor",
     "Business" : "Poslovno",
@@ -363,6 +375,7 @@ OC.L10N.register(
     "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
     "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
     "Imported {filename}" : "Uvezena datoteka {filename}",
+    "Error while parsing a PROPFIND error" : "Pogreška pri obradi PROPFIND pogreške",
     "User not found" : "Korisnik nije pronađen",
     "Hidden" : "Skriveno",
     "can edit" : "uređivanje moguće",
